@@ -9,14 +9,15 @@ ArgConfig &ArgConfig::initialize(char const *optstring,
             string const &fname,
             Comment cType, SearchCasing sType, Indices iType)
 {
-    if (s_argconfig)
+    if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argconfig = new ArgConfig(0, optstring,
-                            begin, end,
-                            argc, argv,
-                            fname,
-                            cType, sType, iType);
+    s_argConfig.reset(new ArgConfig{ 0, optstring,
+                                     begin, end,
+                                     argc, argv,
+                                     fname,
+                                     cType, sType, iType }
+                     );
 
-    return *s_argconfig;
+    return *s_argConfig;
 }
