@@ -1,5 +1,5 @@
 inline IRandStream::IRandStream(int max)
 :
-    Randbuffer(1, max, 1),
+    RandBuf(1, max, 1),
     std::istream(this)
 {}
