@@ -1,4 +1,4 @@
 inline size_t OFoldStream::leftMargin(std::ostream const &os)
 {
-    return OFoldStreambuf::leftMargin(os.rdbuf());
+    return OFoldBuf::leftMargin(os.rdbuf());
 }
